==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by PSAT.rc
//
#define IDB_REPORTREG_BACKGROUND        1
#define IDC_BUTTON_CHECK                3
#define IDC_BUTTON_REWRITE              4
#define IDC_BUTTON_REG                  5
#define IDD_PSAT_DIALOG                 102
#define IDR_MAINFRAME                   128
#define IDD_LOGIN_DIALOG                130
#define IDD_REPORT_CONTENT_DIALOG       137
#define IDD_KEY_MAKING_DIALOG           139
#define IDD_REPLY_LIST_DIALOG           140
#define IDB_MAIN_BACKGROUND             170
#define IDB_INFORMATION                 171
#define IDB_MAIN_MENU_HOME_BACK         172
#define IDB_MAIN_MENU_HOME_NORMAL       173
#define IDB_MAIN_MENU_HOME_OVER         174
#define IDB_MAIN_MENU_HOME_DOWN         175
#define IDB_MAIN_MENU_VER_BACK          176
#define IDB_MAIN_MENU_VER_NORMAL        177
#define IDB_MAIN_MENU_VER_DOWN          178
#define IDB_MAIN_MENU_VER_OVER          179
#define IDB_MAIN_MENU_REG_BACK          180
#define IDB_MAIN_MENU_REG_NORMAL        181
#define IDB_MAIN_MENU_REG_DOWN          182
#define IDB_MAIN_MENU_REG_OVER          183
#define IDB_LOGIN                       184
#define IDB_LOGOUT                      185
#define IDB_REG_RESET_NORMAL            189
#define IDB_REG_RESET_OVER              190
#define IDB_REG_REPORT_OVER             191
#define IDB_REG_REPORT_NORMAL           192
#define IDB_REG_SEARCH_OVER             193
#define IDB_REG_SEARCH_NORMAL           194
#define IDB_SUB_BACKGROUND_REGISTER     195
#define IDB_SUB_BACKGROUND_VERTIFICATION 197
#define IDB_VER_VER_OVER                198
#define IDB_VER_VER_NORMAL              199
#define IDB_VER_REPORT_OVER             200
#define IDB_VER_REPORT_NORMAL           201
#define IDB_VER_SEARCH_OVER             202
#define IDB_VER_SEARCH_NORMAL           203
#define IDB_VER_VIEWREPLY_OVER          204
#define IDB_VER_VIEWREPLY_NORMAL        205
#define IDB_VER_VIEWREPORT_OVER         206
#define IDB_VER_VIEWREPORT_NORMAL       207
#define IDB_LOGINDLG_BTN_JOIN_CLICK     208
#define IDB_LOGINDLG_BTN_GUEST_CLICK    209
#define IDB_LOGINDLG_BTN_GEUST_NORMAL   210
#define IDB_LOGINDLG_BTN_CONNECT_CLICK  211
#define IDB_LOGINDLG_BTN_CONNECT_NORMAL 212
#define IDB_LOGINDLG_BTN_JOIN_NORMAL    214
#define IDB_LOGINDLG_BACKGROUND         222
#define IDD_KMESSAGEBOX_DIALOG          225
#define IDB_KMB_OK_CLICK                226
#define IDB_KMB_NO_CLICK                228
#define IDB_KMB_NO_NORMAL               229
#define IDB_KMB_YES_CLICK               230
#define IDB_KMB_YES_NORMAL              231
#define IDB_KMB_OK_NORMAL               232
#define IDB_REPLYLIST_REMOVE            235
#define IDB_REPLYLIST_REMOVE_NORMAL     235
#define IDB_REPLYLIST_REGISTER_NORMAL   236
#define IDB_REPLYLIST_REGISTER_CLICK    237
#define IDB_KMB_BACKGROUND              239
#define IDD_REPORT_LIST_DIALOG          240
#define IDB_REPORTLIST_BACKGROUND       244
#define IDB_KEYMAKINGDLG_BACKGROUND     245
#define IDD_MEMBER_JOIN_DIALOG          246
#define IDB_JOINDLG_BTN_JOIN_CLICK      247
#define IDB_JOINDLG_BTN_JOIN_NORMAL     248
#define IDB_JOINDLG_BTN_CANCEL_CLICK    249
#define IDB_JOINDLG_BTN_CANCEL_NORMAL   250
#define IDD_REGISTER_REPORT_DIALOG      254
#define IDB_REPORTREG_REG_CLICK         255
#define IDB_REPORTREG_CANCLE_NORMAL     256
#define IDB_REPORTREG_CANCLE_CLICK      257
#define IDB_REPORTREG_REG_NORMAL        259
#define IDB_JOINDLG_BACKGROUND          260
#define IDB_SUB_BACKGROUND_HOME         261
#define IDB_REPLYLIST_BACKGROUND        262
#define IDD_INFOMATION_DIALOG           263
#define IDB_INFODLG_BACKGROUND          265
#define IDB_REPLYLIST_RIGHT_CUR_NORMAL  267
#define IDB_REPLYLIST_LEFT_CUR_NORMAL   269
#define IDB_REPLYLIST_REMOVE_CLICK      274
#define IDB_SDLG_CLOSE_NORMAL           276
#define IDB_SDLG_CLOSE_CLICK            278
#define IDB_SDLG_CLOSE_OVER             279
#define IDB_MDLG_CLOSE_CLICK            280
#define IDB_MDLG_CLOSE_NORMAL           281
#define IDB_MDLG_CLOSE_OVER             282
#define IDB_MDLG_MINIMAM_CLICK          283
#define IDB_MDLG_MINIMAM_NORMAL         284
#define IDB_MDLG_MINIMAM_OVER           285
#define IDB_REPLYLIST_LEFT_CUR_CLICK    287
#define IDB_REPLYLIST_RIGHT_CUR_CLICK   288
#define IDC_EDIT_FILE_PATH              1002
#define IDC_EDIT_PROGRAM_NAME           1003
#define IDC_BUTTON_DIRECTORY            1004
#define IDC_BUTTON_FILE                 1005
#define IDC_EDIT_COMPANY_NAME           1006
#define IDC_EDIT_VERSION                1007
#define IDC_PROGRESS1                   1008
#define IDC_EDIT_DEPENDENCE             1009
#define IDC_BUTTON_VIEW_REPLY           1010
#define IDC_EDT_ID                      1011
#define IDC_EDIT_ADD_INFORMATION        1011
#define IDC_EDT_PASS                    1012
#define IDC_BUTTON_LOGIN                1013
#define IDC_COMBO_COMPANY               1017
#define IDC_COMBO_PROGRAM               1018
#define IDC_COMBO_VERSION               1019
#define IDC_EDIT_ADD_CONTENT            1020
#define IDC_TAB1                        1021
#define IDC_STATIC_ADD_INFO             1024
#define IDC_STATIC_PROGRAM              1026
#define IDC_STATIC_COMPANY              1027
#define IDC_STATIC_VERSION              1028
#define IDC_STATIC_ADD_CONTENT          1029
#define IDC_STATIC_REG_COMPANY          1030
#define IDC_STATIC_REG_PROGRAM          1031
#define IDC_STATIC_REG_VERSION          1032
#define IDC_STATIC_REG_ADD_CONTENT      1034
#define IDC_EDIT_REG_ADD_CONTENT        1035
#define IDC_EDIT_REG_COMPANY            1036
#define IDC_EDIT_REG_PROGRAM            1037
#define IDC_EDIT_REG_VERSION            1038
#define IDC_EDIT_REG_PATH               1039
#define IDC_BUTTON_REG_FILE             1040
#define IDC_BUTTON_REG_DIRECTORY        1041
#define IDC_COMBO_REG_COMPANY           1042
#define IDC_COMBO_REG_PROGRAM           1043
#define IDC_COMBO_REG_VERSION           1044
#define IDC_EDIT_SEAR_STRING            1045
#define IDC_BUTTON_SEAR_SEARCH          1046
#define IDC_LIST_SEAR_LIST              1047
#define IDC_COMBO_SEARCH_INDEX          1048
#define IDC_BUTTON_TEST                 1050
#define IDC_BUTTON_GUEST                1051
#define IDC_BUTTON_REPORT               1052
#define IDC_BUTTON_JOIN_MEMBER          1053
#define IDC_EDIT_REPORT_CONTENT         1054
#define IDC_BUTTON_SEARCH_PATH          1055
#define IDC_COMBO_FILE_DIR              1056
#define IDC_BUTTON_REG_SEARCH_PATH      1057
#define IDC_COMBO_REG_FILEDIRECTORY     1058
#define IDC_STATIC_PER                  1060
#define IDC_STATIC_PATH                 1061
#define IDC_CHECK_RECORD_ID             1061
#define IDC_LIST_REPLY                  1062
#define IDC_BUTTON_LEFT_MOVE            1063
#define IDC_BUTTON_RIGHT_MOVE           1064
#define IDC_EDIT_WRITE_TEXT             1065
#define IDC_BUTTON_REGISTER_RELPY       1066
#define IDC_BUTTON_REMOVE_REPLY         1067
#define IDC_EDIT_READ_TEXT              1068
#define IDC_BUTTON_MENU_HOME            1070
#define IDC_BUTTON_MENU_VERTIFICATION   1071
#define IDC_BUTTON_MENU_REGISTER        1072
#define IDC_BUTTON_INFO                 1073
#define IDC_BUTTON_LOGOUT               1074
#define IDC_BUTTON_EXIT                 1075
#define IDC_BUTTON_MINIMAM              1076
#define IDC_BUTTON_VIEW_REPORT          1077
#define IDC_BUTTON_CLOSE                1078
#define IDC_BUTTON_OK                   1080
#define IDC_BUTTON_YES                  1081
#define IDC_BUTTON_NO                   1082
#define IDC_EDIT_MESSAGE                1083
#define IDC_LIST1                       1088
#define IDC_EDIT_READ_CONTENT           1089
#define IDC_BUTTON_JOIN                 1090
#define IDC_BUTTON_CANCEL               1091
#define IDC_EDIT_ID                     1092
#define IDC_EDIT_PASS1                  1093
#define IDC_EDIT_PASS2                  1094
#define IDC_EDIT_MAIL                   1095
#define IDC_BUTTON_REGISTER             1096
#define IDC_EDIT_CONTENTS               1098
#define IDC_STATIC_VER_GUEST_STATE      1100
#define IDC_STATIC_VER_MEMBER_STATE     1101

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        289
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1102
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> 3050-PostSoftwareAssuranceTool-1.2.0-1.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by PSAT.rc
//
#define IDC_BUTTON_CHECK                3
#define IDC_BUTTON_REWRITE              4
#define IDC_BUTTON_REG                  5
#define IDD_PSAT_DIALOG                 102
#define IDR_MAINFRAME                   128
#define IDD_LOGIN_DIALOG                130
#define IDD_REPORT_CONTENT_DIALOG       137
#define IDD_KEY_MAKING_DIALOG           139
#define IDD_REPLY_LIST_DIALOG           140
#define IDB_MAIN_BACKGROUND             170
#define IDB_INFORMATION                 171
#define IDB_MAIN_MENU_HOME_BACK         172
#define IDB_MAIN_MENU_HOME_NORMAL       173
#define IDB_MAIN_MENU_HOME_OVER         174
#define IDB_MAIN_MENU_HOME_DOWN         175
#define IDB_MAIN_MENU_VER_BACK          176
#define IDB_MAIN_MENU_VER_NORMAL        177
#define IDB_MAIN_MENU_VER_DOWN          178
#define IDB_MAIN_MENU_VER_OVER          179
#define IDB_MAIN_MENU_REG_BACK          180
#define IDB_MAIN_MENU_REG_NORMAL        181
#define IDB_MAIN_MENU_REG_DOWN          182
#define IDB_MAIN_MENU_REG_OVER          183
#define IDB_LOGIN                       184
#define IDB_LOGOUT                      185
#define IDB_REG_RESET_NORMAL            189
#define IDB_REG_RESET_OVER              190
#define IDB_REG_REPORT_OVER             191
#define IDB_REG_REPORT_NORMAL           192
#define IDB_REG_SEARCH_OVER             193
#define IDB_REG_SEARCH_NORMAL           194
#define IDB_SUB_BACKGROUND_REGISTER     195
#define IDB_VER_SEARCH_OVER             202
#define IDB_VER_SEARCH_NORMAL           203
#define IDB_VER_VIEWREPLY_OVER          204
#define IDB_VER_VIEWREPLY_NORMAL        205
#define IDB_VER_VIEWREPORT_OVER         206
#define IDB_VER_VIEWREPORT_NORMAL       207
#define IDB_LOGINDLG_BTN_JOIN_CLICK     208
#define IDB_LOGINDLG_BTN_GUEST_CLICK    209
#define IDB_LOGINDLG_BTN_GEUST_NORMAL   210
#define IDB_LOGINDLG_BTN_CONNECT_CLICK  211
#define IDB_LOGINDLG_BTN_CONNECT_NORMAL 212
#define IDB_LOGINDLG_BTN_JOIN_NORMAL    214
#define IDB_LOGINDLG_BACKGROUND         222
#define IDD_KMESSAGEBOX_DIALOG          225
#define IDB_KMB_OK_CLICK                226
#define IDB_KMB_NO_CLICK                228
#define IDB_KMB_NO_NORMAL               229
#define IDB_KMB_YES_CLICK               230
#define IDB_KMB_YES_NORMAL              231
#define IDB_KMB_OK_NORMAL               232
#define IDB_REPLYLIST_REMOVE            235
#define IDB_REPLYLIST_REMOVE_NORMAL     235
#define IDB_KMB_BACKGROUND              239
#define IDD_REPORT_LIST_DIALOG          240
#define IDB_KEYMAKINGDLG_BACKGROUND     245
#define IDD_MEMBER_JOIN_DIALOG          246
#define IDB_JOINDLG_BTN_JOIN_CLICK      247
#define IDB_JOINDLG_BTN_JOIN_NORMAL     248
#define IDB_JOINDLG_BTN_CANCEL_CLICK    249
#define IDB_JOINDLG_BTN_CANCEL_NORMAL   250
#define IDD_REGISTER_REPORT_DIALOG      254
#define IDB_REPORTREG_REG_CLICK         255
#define IDB_REPORTREG_CANCLE_NORMAL     256
#define IDB_REPORTREG_CANCLE_CLICK      257
#define IDB_REPORTREG_REG_NORMAL        259
#define IDB_JOINDLG_BACKGROUND          260
#define IDB_SUB_BACKGROUND_HOME         261
#define IDD_INFOMATION_DIALOG           263
#define IDB_INFODLG_BACKGROUND          265
#define IDB_REPLYLIST_RIGHT_CUR_NORMAL  267
#define IDB_REPLYLIST_LEFT_CUR_NORMAL   269
#define IDB_REPLYLIST_REMOVE_CLICK      274
#define IDB_SDLG_CLOSE_NORMAL           276
#define IDB_SDLG_CLOSE_CLICK            278
#define IDB_SDLG_CLOSE_OVER             279
#define IDB_MDLG_CLOSE_CLICK            280
#define IDB_MDLG_CLOSE_NORMAL           281
#define IDB_MDLG_CLOSE_OVER             282
#define IDB_MDLG_MINIMAM_CLICK          283
#define IDB_MDLG_MINIMAM_NORMAL         284
#define IDB_MDLG_MINIMAM_OVER           285
#define IDB_REPLYLIST_LEFT_CUR_CLICK    287
#define IDB_REPLYLIST_RIGHT_CUR_CLICK   288
#define IDB_VER_COUNT_0                 289
#define IDB_VER_COUNT_1                 290
#define IDB_VER_COUNT_2                 291
#define IDB_VER_COUNT_3                 292
#define IDB_VER_COUNT_4                 293
#define IDB_VER_COUNT_5                 294
#define IDB_VER_COUNT_6                 295
#define IDB_VER_COUNT_7                 296
#define IDB_VER_COUNT_8                 297
#define IDB_VER_COUNT_9                 298
#define IDB_VER_BAR_START               303
#define IDB_VER_BAR_MID                 304
#define IDB_VER_BAR_END                 305
#define IDB_VER_VER_NORMAL              306
#define IDB_VER_VER_OVER                307
#define IDR_ICON32_32                   308
#define IDB_SUB_BACKGROUND_VERTIFICATION 309
#define IDB_VER_REPORT_NORMAL           312
#define IDB_VER_REPORT_OVER             313
#define IDR_ICON16_16                   314
#define IDB_REPORTREG_BACKGROUND        315
#define IDB_BITMAP2                     317
#define IDB_REPORTLIST_BACKGROUND       317
#define IDB_REPLYLIST_BACKGROUND        318
#define IDB_REPLYLIST_REGISTER_NORMAL   321
#define IDB_REPLYLIST_REGISTER_CLICK    322
#define IDC_EDIT_FILE_PATH              1002
#define IDC_EDIT_PROGRAM_NAME           1003
#define IDC_BUTTON_DIRECTORY            1004
#define IDC_BUTTON_FILE                 1005
#define IDC_EDIT_COMPANY_NAME           1006
#define IDC_EDIT_VERSION                1007
#define IDC_PROGRESS1                   1008
#define IDC_EDIT_DEPENDENCE             1009
#define IDC_BUTTON_VIEW_REPLY           1010
#define IDC_EDT_ID                      1011
#define IDC_EDIT_ADD_INFORMATION        1011
#define IDC_EDT_PASS                    1012
#define IDC_BUTTON_LOGIN                1013
#define IDC_COMBO_COMPANY               1017
#define IDC_COMBO_PROGRAM               1018
#define IDC_COMBO_VERSION               1019
#define IDC_EDIT_ADD_CONTENT            1020
#define IDC_TAB1                        1021
#define IDC_STATIC_ADD_INFO             1024
#define IDC_STATIC_PROGRAM              1026
#define IDC_STATIC_COMPANY              1027
#define IDC_STATIC_VERSION              1028
#define IDC_STATIC_ADD_CONTENT          1029
#define IDC_STATIC_REG_COMPANY          1030
#define IDC_STATIC_REG_PROGRAM          1031
#define IDC_STATIC_REG_VERSION          1032
#define IDC_STATIC_REG_ADD_CONTENT      1034
#define IDC_EDIT_REG_ADD_CONTENT        1035
#define IDC_EDIT_REG_COMPANY            1036
#define IDC_EDIT_REG_PROGRAM            1037
#define IDC_EDIT_REG_VERSION            1038
#define IDC_EDIT_REG_PATH               1039
#define IDC_BUTTON_REG_FILE             1040
#define IDC_BUTTON_REG_DIRECTORY        1041
#define IDC_COMBO_REG_COMPANY           1042
#define IDC_COMBO_REG_PROGRAM           1043
#define IDC_COMBO_REG_VERSION           1044
#define IDC_EDIT_SEAR_STRING            1045
#define IDC_BUTTON_SEAR_SEARCH          1046
#define IDC_LIST_SEAR_LIST              1047
#define IDC_COMBO_SEARCH_INDEX          1048
#define IDC_BUTTON_TEST                 1050
#define IDC_BUTTON_GUEST                1051
#define IDC_BUTTON_REPORT               1052
#define IDC_BUTTON_JOIN_MEMBER          1053
#define IDC_EDIT_REPORT_CONTENT         1054
#define IDC_BUTTON_SEARCH_PATH          1055
#define IDC_COMBO_FILE_DIR              1056
#define IDC_BUTTON_REG_SEARCH_PATH      1057
#define IDC_COMBO_REG_FILEDIRECTORY     1058
#define IDC_STATIC_PER                  1060
#define IDC_STATIC_PATH                 1061
#define IDC_CHECK_RECORD_ID             1061
#define IDC_LIST_REPLY                  1062
#define IDC_BUTTON_LEFT_MOVE            1063
#define IDC_BUTTON_RIGHT_MOVE           1064
#define IDC_EDIT_WRITE_TEXT             1065
#define IDC_BUTTON_REGISTER_RELPY       1066
#define IDC_BUTTON_REMOVE_REPLY         1067
#define IDC_EDIT_READ_TEXT              1068
#define IDC_BUTTON_MENU_HOME            1070
#define IDC_BUTTON_MENU_VERTIFICATION   1071
#define IDC_BUTTON_MENU_REGISTER        1072
#define IDC_BUTTON_INFO                 1073
#define IDC_BUTTON_LOGOUT               1074
#define IDC_BUTTON_EXIT                 1075
#define IDC_BUTTON_MINIMAM              1076
#define IDC_BUTTON_VIEW_REPORT          1077
#define IDC_BUTTON_CLOSE                1078
#define IDC_BUTTON_OK                   1080
#define IDC_BUTTON_YES                  1081
#define IDC_BUTTON_NO                   1082
#define IDC_EDIT_MESSAGE                1083
#define IDC_LIST1                       1088
#define IDC_EDIT_READ_CONTENT           1089
#define IDC_BUTTON_JOIN                 1090
#define IDC_BUTTON_CANCEL               1091
#define IDC_EDIT_ID                     1092
#define IDC_EDIT_PASS1                  1093
#define IDC_EDIT_PASS2                  1094
#define IDC_EDIT_MAIL                   1095
#define IDC_BUTTON_REGISTER             1096
#define IDC_EDIT_CONTENTS               1098
#define IDC_STATIC_VER_GUEST_STATE      1100
#define IDC_STATIC_VER_MEMBER_STATE     1101
#define IDC_STATIC_VER_GUEST_PER        1102
#define IDC_STATIC_VER_MEMBER_PER       1103
#define IDC_STATIC_MESSAGE              1104
#define IDC_STATIC_READ_CONTENT         1105
#define IDC_STATIC_READ_TEXT            1106

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        323
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1107
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
